@@ -2,7 +2,7 @@ package Redis::Namespace;
 
 use strict;
 use warnings;
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Redis;
 
@@ -191,7 +191,8 @@ sub add_namespace {
         } elsif($type eq 'HASH') {
             my %hash;
             while (my ($key, $value) = each %$item) {
-                $hash{$self->add_namespace($key)} = $value;
+                my ($new_key) = $self->add_namespace($key);
+                $hash{$new_key} = $value;
             }
             push @result, \%hash;
         } else {
@@ -210,18 +211,19 @@ sub rem_namespace {
     for my $item(@args) {
         my $type = ref $item;
         if($item && !$type) {
-            $item =~ s/^$namespace://;
+            $item =~ s/^\Q$namespace://;
             push @result, $item;
         } elsif($type eq 'SCALAR') {
             my $tmp = $$item;
-            $tmp =~ s/^$namespace://;
+            $tmp =~ s/^\Q$namespace://;
             push @result, \$tmp;
         } elsif($type eq 'ARRAY') {
             push @result, [$self->rem_namespace(@$item)];
         } elsif($type eq 'HASH') {
             my %hash;
             while (my ($key, $value) = each %$item) {
-                $hash{$self->rem_namespace($key)} = $value;
+                my ($new_key) = $self->rem_namespace($key);
+                $hash{$new_key} = $value;
             }
             push @result, \%hash;
         } else {
